summaryrefslogtreecommitdiff
path: root/src/verify_j2k.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/verify_j2k.h')
-rw-r--r--src/verify_j2k.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/verify_j2k.h b/src/verify_j2k.h
index ac69155c..58c8f4b7 100644
--- a/src/verify_j2k.h
+++ b/src/verify_j2k.h
@@ -51,11 +51,12 @@ namespace dcp {
class Data;
/** @param frame_index Video frame index, so that notes can say which frame contains the problem.
* @param frame_rate Video frame rate (in frames per second) to calculate how big the tile parts
* can be.
*/
-void verify_j2k(std::shared_ptr<const Data> data, int frame_index, int frame_rate, std::vector<VerificationNote>& notes);
+void verify_j2k(std::shared_ptr<const Data> data, int start_index, int frame_index, int frame_rate, std::vector<VerificationNote>& notes);
}
@@ -51,11 +51,12 @@ namespace dcp {
class Data;
-/** @param frame_index Video frame index, so that notes can say which frame contains the problem.
+/** @param start_index Frame index within the DCP where this frame's reel starts.
+ * @param frame_index Video frame index within the reel, so that notes can say which frame contains the problem.
* @param frame_rate Video frame rate (in frames per second) to calculate how big the tile parts
* can be.